package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````VI@$"#0```!PP@```````#0`(``)
M`"@`'0`<``8````T````-(`$"#2`!`@@`0``(`$```4````$`````P```%0!
M``!4@00(5($$"!,````3````!`````$````!``````````"`!`@`@`0($*\`
M`!"O```%`````!````$```#XO@``^$X%"/A.!0@L`@``G!(```8`````$```
M`@````2_```$3P4(!$\%"/@```#X````!@````0````$````:`$``&B!!`AH
M@00(1````$0````$````!````%#E=&10H```4"`%"%`@!0CL````[`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D^+X`
M`/A.!0CX3@4("`$```@!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,@``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`+:(D!U`9JF*TK;XHF3!_H*S*?HXE````1`````@````(`````!P0!"5`
M!((X`4`!HH8!J,`!``)+*`0I.*(R1XH$#`A$````1@``````````````````
M`$@```!*````2P````````!,````30```$\```!0````40```%(`````````
M5```````````````50```%8```!9``````````````!:````7````%T```!?
M`````````&$```!C``````````````!E````9@```&<`````````R-6R<5GH
M[>S.WD<MH^#[2>K3[PZGW:-K+\6;MMO-XYZ'^9R!5J2;EFL)0]8Y\HL<#3J7
M"\6)!9`,%.*>B0=PTR'_Y`X+BA!7Q+F<0&I_FGRS`8MO?ZF<FV[%WQ_9<5@<
MN^.2?*Q+X\#59-1\X*<""C-BV^UZ\$IK9Z_,9D)%U>SC1\8!?4&.Q</E/RSR
MV],=^J%L8+F-\0X`````````````````````X`(`````````````$@```(8#
M`````````````!(````D`@`````````````2````$0``````````````(```
M`/0#`````````````!(```!W`P`````````````2````/0$`````````````
M$@```/L"`````````````!(```#3```````````````2````YP(`````````
M````$@```*\``````````````!(````X`0`````````````2````G@(`````
M````````$@```#0#`````````````!(```"O`@`````````````2````H0$`
M````````````$@```$0#`````````````!(````[`P`````````````2````
M80$`````````````$@```.$``````````````!(```#K`0`````````````2
M````B`$`````````````$@```&T"`````````````!(````<`@``````````
M```2````RP(`````````````$@```-@!`````````````!(```"\`@``````
M```````2````Y`$`````````````$@```&\!`````````````!(```!+`P``
M```````````2````+0``````````````(````'\"`````````````!(```!8
M`P`````````````2````>```````````````$@```-D"`````````````!(`
M``"-`P`````````````2````%0(`````````````$@````\!````````````
M`!(```"^```````````````2````E@$`````````````$@```+8"````````
M`````!(```",`@`````````````2````/0(`````````````$@```,0"````
M`````````!(```!J```````````````2````0@$`````````````$@````(#
M`````````````!(```#-`0`````````````2````'`$`````````````$@``
M`'\#`````````````!(```#2`@`````````````2````KP$`````````````
M$@```#P``````````````"````#S```````````````2````?P$`````````
M````$@```%\#`````````````!(```#M`@`````````````2````AP``````
M````````$@```%```````````````"````"$`@`````````````2````(P,`
M````````````$@```"D"`````````````!(````0`P`````````````2````
M3@(`````````````$@```)4"`````````````!(````;`P`````````````2
M````:0,`````````````$@```$X!```PE00(`````!(```!L!```>-\$"`0`
M```1`!``(@0```#.!`A!#```$@`.`',$``!PR@0(MP$``!(`#@#+`P``9-\$
M"``````2``\`H0,``$!1!0@$````(0`:`-$#``"`QP0(!0```!(`#@!2!```
M`-\$"%T````2``X`G@```."5!`@`````$@```"T!``!0404(!````!$`&@`O
M!```%%$%"``````0`!D`+0,``$A1!0@$````$0`:`#$$```4404(`````"``
M&0"@`P``0%$%"`0````A`!H`P0,``&#?!`@"````$@`.`&($```@404(!```
M`!$`&0"(!```D,<$"+@!```2``X``@$``%11!0@!````$0`:`)\#``!`404(
M!````!$`&@":`P``T)8$"`H"```2``X`IP0``##,!`AI````$@`.`.(#``"@
MS`0()````!(`#@#]`P``(-X$"&D````2``X`L`,``"11!0@`````$``:`+P#
M``"4804(`````!``&@!>`@``?-\$"`0````1`!``T00``%#:!`C.`P``$@`.
M`#P$``#`Q@0(L0```!(`#@`U!```VI@$"``````2``X`O0$``""3!`@`````
M$@```!8$``"`R00(YP```!(`#@"I`P``)%$%"``````0`!D`"00``%#)!`@B
M````$@`.`+4$``"0W@0(.````!(`#@"`!```0,8$""<````2``X`]@$``%A1
M!0@3````$0`:`)4$``#0S`0()@$``!(`#@""!```;)($"``````2``L``&QI
M8G!E<FPN<V\N-2XR,@!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G
M;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R
M;%]S879E7V1E<W1R=6-T;W)?>`!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N
M<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R
M;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E
M<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F
M<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E
M='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7V1O=6YW:6YD`%!E
M<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN
M84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L
M;&]C`%!,7VUE;6]R>5]W<F%P`&QI8G!T:')E860N<V\N,`!O<&5N-C0`;'-E
M96LV-`!R96%D`'!T:')E861?9V5T<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO
M;@!C;&]S90!L:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A
M=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A8VM?
M8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`;65M8VAR`&=E='!I9`!S
M=')T;VL`<W1R;&5N`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P
M>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`
M<W1D97)R`&=E='5I9`!R96%D;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T
M<F-H<@!R96%D9&ER-C0`7U]S<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S
M=')C;7``7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`%]E9&%T80!?7V)S
M<U]S=&%R=`!?96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C
M`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B
M87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T
M`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R
M7W!L`%]F<%]H=P!P87)?:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`
M<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?
M4$%27T-,14%24U1!0TL`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N
M,@!'3$E"0U\R+C``1TQ)0D-?,BXS+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXT
M``````(``@`#`````@`"``(``@````(```````0``@`"`````@`"````````
M````!0`&``(````"``(````'`````@`"`````@`"``8``````````@`"``,`
M`@``````!P```````@`"````````````"``'```````"``@``P`(``,``@`"
M``<````!``$``0`!``(``0`!```````!``(``0`"``$``0`!`````@`!``$`
M`0`!``$``0`!``$``0`!`````0`!``$``0`!`````0`!`````0`"``4"```0
M````,````!)I:0T```8`YP0``!`````0:6D-```#`/$$`````````0`%`%0"
M```0`````````!)I:0T```@`YP0``!````!T&6D)```'`/L$```0````<AEI
M"0``!0`'!0``$````!1I:0T```0`$P4``!`````0:6D-```"`/$$````````
M_$\%"`8?``!`404(!58``$A1!0@%3P``4%$%"`5-``!4404(!54``%A1!0@%
M9P``#%`%"`<!```04`4(!P(``!10!0@'`P``&%`%"`<%```<4`4(!P8``"!0
M!0@'!P``)%`%"`<(```H4`4(!PD``"Q0!0@'80``,%`%"`<*```T4`4(!PL`
M`#A0!0@'#```/%`%"`<-``!`4`4(!PX``$10!0@'#P``2%`%"`<0``!,4`4(
M!Q$``%!0!0@'$@``5%`%"`<3``!84`4(!Q0``%Q0!0@'%0``8%`%"`<6``!D
M4`4(!Q<``&A0!0@'&```;%`%"`<9``!P4`4(!QH``'10!0@'&P``>%`%"`<<
M``!\4`4(!QT``(!0!0@''@``A%`%"`<@``"(4`4(!R$``(Q0!0@'(@``D%`%
M"`<C``"44`4(!R0``)A0!0@')0``G%`%"`<F``"@4`4(!R<``*10!0@'*```
MJ%`%"`<I``"L4`4(!RH``+!0!0@'1```M%`%"`<K``"X4`4(!RP``+Q0!0@'
M+0``P%`%"`<N``#$4`4(!R\``,A0!0@',```S%`%"`<Q``#04`4(!S(``-10
M!0@',P``V%`%"`<T``#<4`4(!TP``.!0!0@'-@``Y%`%"`<W``#H4`4(!S@`
M`.Q0!0@'.0``\%`%"`<Z``#T4`4(!SP``/A0!0@'/0``_%`%"`<^````404(
M!S\```11!0@'0```"%$%"`=!```,404(!T(``!!1!0@'0P``4X/L".B+!@``
M@<.+O0``BX/\____A<!T!>@V!```@\0(6\,`_S4$4`4(_R4(4`4(`````/\E
M#%`%"&@`````Z>#_____)1!0!0AH"````.G0_____R444`4(:!````#IP/__
M__\E&%`%"&@8````Z;#_____)1Q0!0AH(````.F@_____R4@4`4(:"@```#I
MD/____\E)%`%"&@P````Z8#_____)2A0!0AH.````.EP_____R4L4`4(:$``
M``#I8/____\E,%`%"&A(````Z5#_____)310!0AH4````.E`_____R4X4`4(
M:%@```#I,/____\E/%`%"&A@````Z2#_____)4!0!0AH:````.D0_____R5$
M4`4(:'````#I`/____\E2%`%"&AX````Z?#^____)4Q0!0AH@````.G@_O__
M_R504`4(:(@```#IT/[___\E5%`%"&B0````Z<#^____)5A0!0AHF````.FP
M_O___R5<4`4(:*````#IH/[___\E8%`%"&BH````Z9#^____)610!0AHL```
M`.F`_O___R5H4`4(:+@```#I</[___\E;%`%"&C`````Z6#^____)7!0!0AH
MR````.E0_O___R5T4`4(:-````#I0/[___\E>%`%"&C8````Z3#^____)7Q0
M!0AHX````.D@_O___R6`4`4(:.@```#I$/[___\EA%`%"&CP````Z0#^____
M)8A0!0AH^````.GP_?___R6,4`4(:``!``#IX/W___\ED%`%"&@(`0``Z=#]
M____)910!0AH$`$``.G`_?___R684`4(:!@!``#IL/W___\EG%`%"&@@`0``
MZ:#]____):!0!0AH*`$``.F0_?___R6D4`4(:#`!``#I@/W___\EJ%`%"&@X
M`0``Z7#]____):Q0!0AH0`$``.E@_?___R6P4`4(:$@!``#I4/W___\EM%`%
M"&A0`0``Z4#]____);A0!0AH6`$``.DP_?___R6\4`4(:&`!``#I(/W___\E
MP%`%"&AH`0``Z1#]____)<10!0AH<`$``.D`_?___R7(4`4(:'@!``#I\/S_
M__\ES%`%"&B``0``Z>#\____)=!0!0AHB`$``.G0_/___R744`4(:)`!``#I
MP/S___\EV%`%"&B8`0``Z;#\____)=Q0!0AHH`$``.F@_/___R7@4`4(:*@!
M``#ID/S___\EY%`%"&BP`0``Z8#\____)>A0!0AHN`$``.EP_/___R7L4`4(
M:,`!``#I8/S___\E\%`%"&C(`0``Z5#\____)?10!0AHT`$``.E`_/___R7X
M4`4(:-@!``#I,/S___\E_%`%"&C@`0``Z2#\____)0!1!0AHZ`$``.D0_/__
M_R4$404(:/`!``#I`/S___\E"%$%"&CX`0``Z?#[____)0Q1!0AH``(``.G@
M^____R40404(:`@"``#IT/O___\E_$\%"&:0``````````"-3"0$@^3P_W'\
M58GE5E-1B<N#[#"+002)1=2+00B)1=!EH10```")1>0QP(U%T%"-1=104>B6
M_?__@\0,:#"5!`AH,)4$"&C@E00(Z*]'``"#Q!"`/511!0@`=3'HKOS__X7`
MHY!A!0@/A)$!``"#[`Q0Z/C[__]9_S50404(Z`S___^#Q!#&@'D%````@^P,
M_S50404(Z/3^__^`B`H#```"6O\U4%$%".CA_O__@(@*`P```8L#@\00@\`%
M/?___S\/AP4!``"#[`S!X`)0Z(O\__^+==2+&X/$$*.$804(QP6(804(!```
M`(L6@_L!QT`$6^$$",=`#%[A!`B)$(L5(%$%"(E0"+H!````?A6-M"8`````
MBPR6B4R0#(/"`3G:=?*#[`S'1)@,`````(/#`VH`4%-H<,8$"/\UD&$%".AX
M_?__@\0@A<")PW11@^P,_S60804(Z&'[__^-5>"X'^`$".B4)@``@\00A<!T
M1(/L#/\UD&$%".C_^O__Z`K]__^#Q!")V(MUY&4S-10```!U9(UE]%E;7EV-
M8?S#@^P,_S60804(Z(#]__^#Q!")P^N:H8QA!0B%P'0?@^P,4.B'10``@\00
MZZ504&A8404(:,_?!`CH0?S__XU5X+C4WP0(Z!0F``"%P*.,804(#X1Z____
MZ\7HD/K__X/L#&H!Z*;[__\Q[5Z)X8/D\%!44FA@WP0(:`#?!`A15FC0E@0(
MZ,7[___T9I!FD(L<),-FD&:09I!FD&:09I"X)U$%""TD404(@_@&=AJX````
M`(7`=!%5B>6#[!1H)%$%"/_0@\00R?/#D(UT)@"X)%$%""TD404(P?@"B<+!
MZA\!T-'X=!NZ`````(72=!)5B>6#[!!0:"11!0C_TH/$$,GSPXUT)@"-O"<`
M````@#UK404(`'4358GE@^P(Z'S____&!6M1!0@!R?/#9I"X`$\%"(L0A=)U
M!>N3C78`N@````"%TG3R58GE@^P44/_2@\00R>EU____9I!FD)!55XUH.%93
M@>P,`P``B40D/(V$)(````")?"0,98L5%````(F4)/P"```QTHGOB70D"(G%
MC70F`(L'BU<$,=O'1?P`````@\40@\<(#\B)UHG1B47HB=#!YAC!X`B)VB4`
M`/\`"?")QHG(#ZS0&,'J&`G&B<B)%"0/K-@()0#_```)\(E%\(L$)(E%](V$
M)``!```YZ'6AC80DX````(V4).`"``"-=@"+&(M(!(/`"#-8T#-(U#-8H#-(
MI#-8D#-(E,=`%`````")WHG/B=D!\8G[B0PDB?$/K/D?"PPD#Z3S`8E<)`2)
M2!`YT'6ZBT0D/(LXBV@$BW`8B?J+>`B)Z8MH#(ET)`B)RXMP((E,)!2)T8E\
M)!B+>!");"0<BV@4B70D6(G6B50D$(D\)(MX','F!0^LV1N);"0$B?4QTHE\
M)`R+>"0)S8MT)%@#="1XB>B)?"1<BWPD7!-\)'R)\8'!F7F"6HG[@],``<B+
M3"08$=J+'"2)1"0@B50D)(M4)`B)W3'5B>\ASXGZBWPD"#'ZBWPD((M$)!B+
M'"2+3"00QT0D)`````#'1"0T``````'7BU0D'(G&B7PD*(E\)"")Q\'F'@^L
MUP*)]8MT)`@)_0.T)(````"+?"0,$[PDA````(EL)#")\(MT)`0%F7F"6HGZ
MB=^#T@`Q[R-T)!0ASS,\)#-T)`2)^8GS`<&+1"0@$=.+5"0DB4PD0(E<)$2+
M7"1`B<8/K-`;BU0D%,'F!8G!BT0D$`GQ`<LQ_XG!B=Z)7"10#ZS0`L'A'@G!
MBT0D*(E,)$`QZ2'(B<*+!"0QZ@.$)(@```")T069>8):`<&)\,'@!8E$)"B)
M\(ML)"@/K/@;BU0D),=$)"P`````B40D2`ML)$B+1"0@QT0D)``````!Z8E,
M)"B)3"1@B<'!X1X/K-`"BU0D0(G-"<6+1"10B6PD2(G3,>LAV#'0BU0D+(G!
MBT0D,`.$))`````%F7F"6@'!BT0D*,'@!8E$)""+1"0HBVPD(`^LT!N)1"0P
M"VPD,(M$)$`!Z8E,)"")3"10B?'!X1X/K/X"B<N+C"28````BWPD2`GSBW0D
M8(G:B5PD0('!F7F"6@'!,?J+1"0@(=:+5"0DB?4Q_8G&`>G!Y@4/K-`;B40D
M,(ML)#"+1"0HBU0D+,=$)#0`````QT0D+``````)]8MT)$`!Z8E,)&")3"0P
MB<'!X1Z)]0^LT`*+E"2@````B<L)PXM$)$B)7"1`@<*9>8):B=&+5"0T`<$Q
MW8GHBVPD4"'%BT0D,(GO,?<!^<'@!8G'BT0D,`^LT!N+5"0DQT0D)`````")
M1"0H"WPD*(M$)"`!^8M\)$")3"0HB4PD4(G!#ZS0`HN4)*@```#!X1Z)S0G%
M@<*9>8):B6PD2(G1B?H!\3'J(U0D8(G5,?V+?"0H`>F+;"0LB?C!X`6)1"0@
MB?@/K.@;BVPD(`G%`>F)3"1@B4PD((M\)#"+;"0TBT0D0,=$)#0`````B?J)
M_HM\)$C!XAZ)TXN4)+`````/K.X""?.!PIEY@EJ+="10B=&)VHE<)$`!P3'Z
MBT0D("'6BU0D)(GU,?V)Q@'IP>8%#ZS0&XM4)"R)R\=$)"P`````B40D,(M$
M)"B+;"0PB<$)]8MT)$`!Z\'A'@^LT`*+E"2X````B5PD,(GUB5PD4(G+"<.+
M1"1(@<*9>8):B5PD0(G1BU0D-`'!,=V)Z(ML)&`AQ8M$)#")[S'W`?G!X`6)
MQXM$)#`/K-`;BU0D)(E$)"@+?"0HBT0D(`'YB4PD8(E,)"B)P0^LT`*+E"3`
M````P>$>BWPD0(G-QT0D)``````)Q8'"F7F"6HEL)$B)T8GZ`?$QZB-4)%")
MU3']BWPD*`'IBVPD+(GXP>`%B40D((GXBWPD,`^LZ!N+;"0@B?J)_HM\)$@)
MQ8M$)$`!Z8ML)#3!XAZ)TXN4),@```")3"10B4PD(,=$)#0`````#ZSN`@GS
M@<*9>8):BW0D8(G1B=J)7"1``<$Q^HM$)"`AUHM4)"2)]3']B<8!Z<'F!0^L
MT!N+5"0LB40D,(ML)#"+1"0H"?6+="1``>F)3"0PB4PD8(G!P>$>B?4/K-`"
MBY0DT````(G+"<.+1"1(B5PD0('"F7F"6HG1`<$QW8GHBVPD4"'%BT0D,(GO
M,?<!^<'@!8G'BT0D,(M4)#3'1"0L``````^LT!N+5"0DQT0D)`````")1"0H
M"WPD*(M$)"`!^8M\)$")3"10B4PD*(G!#ZS0`HN4)-@```#!X1Z)S0G%@<*9
M>8):B6PD2(G1B?H!\3'J(U0D8(G5,?V+?"0H`>F+;"0LB?C!X`6)1"0@B?B+
M?"0P#ZSH&XML)"")^HG^BWPD2`G%BT0D0`'IBVPD-,'B'HG3BY0DX````(E,
M)"")3"1@#ZSN`@GS@<*9>8):BW0D4(G1B=J)7"1``<$Q^HM$)"`AUHM4)"2)
M]3']B<8!Z<'F!0^LT!N)RXE$)#"+;"0P"?4!ZXE<)%")7"0PBT0D*(M4)"R+
M="1`QT0D-`````#'1"0L`````(G!P>$>B?4/K-`"B<N+C"3H````BU0D-`G#
MBT0D2(E<)$"!P9EY@EH!P3'=B>B+;"1@(<6+1"0PB>\Q]P'YP>`%B<>+1"0P
M#ZS0&XM4)"3'1"0D`````(E$)"@+?"0HBT0D(`'YBWPD0(E,)"B)3"1@B<'!
MX1Z)S8N,)/`````/K-`"B?H)Q8'!F7F"6@'Q,>HC5"10B6PD2(G5,?V+?"0H
M`>F+;"0LB?C!X`6)1"0@B?B+?"0P#ZSH&XML)"")^HG^"<4!Z8ML)#3!XAZ)
MTXN4)/@```")3"10B4PD((M$)$`/K.X"BWPD2,=$)#0`````"?.!PIEY@EJ+
M="1@B=&)VHE<)$`!P3'ZBT0D("'6BU0D)(GU,?V)Q@'IP>8%#ZS0&XM4)"S'
M1"0L`````(E$)#"+;"0PBT0D*`GUBW0D0`'IB4PD,(E,)&")P<'A'HGU#ZS0
M`HN4)``!``")RPG#BT0D2(E<)$"!PIEY@EJ)T8M4)#0!P3'=B>B+;"10(<6+
M1"0PB>\Q]P'YP>`%B<>+1"0P#ZS0&XM4)"2)1"0H"WPD*(M$)"`!^8M\)$")
M3"10B4PD*(G!#ZS0`HN4)`@!``#!X1Z)S0G%@<*9>8):B6PD2(G1B?H!\3'J
M(U0D8(G5,?V+?"0HQT0D)``````!Z8ML)"R)^,'@!8E$)"")^(M\)#`/K.@;
MBVPD((GZB?X)Q8M$)$`!Z8ML)#3!XAZ)TXN4)!`!``")3"1@B4PD((M\)&`/
MK.X"BVPD2,=$)#0`````"?.!PIEY@EJ)T8M4)$B)7"1``<&+1"10,=HAT(M4
M)"0QQ8M$)"`!Z8G+B<8/K-`;BU0D+,'F!8E$)#"+1"0HBVPD,(G!"?4!Z\'A
M'HML)$`/K-`"B5PD,(E<)%")RXN4)!@!```)PXM$)$B!PJ'KV6X!T#'=BU0D
M-#'OB?D!P8M$)##!X`6)QXM$)#`/K-`;B40D*(ML)"B+1"0@BU0D)(E<)$C'
M1"0L``````G]QT0D)``````!Z8E,)&")3"0HB<'!X1Z+?"0H#ZS0`HG-BY0D
M(`$```G%BT0D0(EL)$"!PJ'KV6X!T#'KBVPD4#'=B>F+;"0L`<&)^,'@!8E$
M)"")^(M\)#`/K.@;BVPD((GZB?Z+?"1@"<6+1"1(`>F+;"0TP>(>B4PD((E,
M)%`/K.X"B=6+E"0H`0``"?6);"1(@<*AZ]EN`=`S;"1`BU0D)#'OB?D!P8M$
M)"")Q@^LT!O!Y@6+5"0LB40D,(ML)#"+1"0H"?4!Z3'_B<Z)3"1@B<'!X1X/
MK-`"B<L)PXE<)#"+E"0P`0``BXPD-`$``(M$)$"+;"1(@<*AZ]EN@]$`B<N)
MT3'2`<@1VC-L)#")1"0HB50D+(M4)%")\(M<)##'1"0L`````#'JB=$#3"0H
MP>`%B40D*(GPBVPD*`^L^!N+5"0DB40D0`ML)$"+1"0@`>F)3"0HB4PD4(G!
MP>$>#ZS0`HG-BY0D.`$```G%BT0D2(EL)$"!PJ'KV6X!T#'KBVPD8(M4)"PQ
MW8GI`<&+1"0HP>`%B40D((M$)"B+;"0@#ZS0&XGRB40D2`ML)$@!Z<'B'HE,
M)&")U8E,)""+E"1``0``BT0D,`^L_@*+?"10QT0D)``````)]8'"H>O9;L=$
M)#0``````=");"1(,VPD0(M4)"0Q[XGYBWPD8`'!BT0D((G+B<8/K-`;BU0D
M+,'F!<=$)"P`````B40D,(M$)"B+;"0PB<$)]0'KP>$>BVPD2`^LT`*)7"0P
MB5PD4(G+BY0D2`$```G#BT0D0('"H>O9;@'0,=V+5"0T,>^)^0'!BT0D,,'@
M!8G'BT0D,`^LT!N+5"0DB40D*`M\)"B+1"0@`?F)3"1@B4PD*(G!P>$>#ZS0
M`HG-BY0D4`$```G%BT0D2(E<)$B);"1`BWPD*('"H>O9;L=$)"0``````=`Q
MZXML)%`QW8GIBVPD+`'!B?C!X`6)1"0@B?B+?"0P#ZSH&XML)"")^HG^BWPD
M8`G%BT0D2`'IBVPD-,'B'HE,)%")3"0@#ZSN`HG5BY0D6`$```GUB6PD2('"
MH>O9;@'0,VPD0(M4)"0Q[XGY`<&+1"0@B<8/K-`;P>8%BU0D+(E$)#"+;"0P
MBT0D*`GU`>DQ_XML)$B)SHE,)&")P<'A'@^LT`*+E"1@`0``B<N+C"1D`0``
M"<.+1"1`B5PD,('"H>O9;H/1`(G+B=$QT@'($=HS;"0PB40D*(E4)"R+5"10
MB?`QZHG1`TPD*,'@!8E$)"B)\(ML)"@/K/@;BU0D)(M<)#")1"1`"VPD0(M$
M)"#'1"0L`````,=$)"0``````>F)3"0HB4PD4(G!P>$>#ZS0`HG-BY0D:`$`
M``G%BT0D2(EL)$"!PJ'KV6X!T#'KBVPD8(M4)"PQW8GI`<&+1"0HP>`%B40D
M((M$)"B+;"0@#ZS0&XGRB40D2`ML)$B+1"0P`>G!XAZ)U8N4)'`!``")3"0@
M#ZS^`HM\)%")3"1@"?6!PJ'KV6X!T(EL)$@S;"1`BU0D)#'OB?D!P8M$)"")
MRXG&#ZS0&\'F!8E$)#"+1"0HBVPD,(M4)"R+?"1@QT0D-`````")P<=$)"P`
M````"?4!Z\'A'HML)$@/K-`"B5PD4(E<)#")RXN4)'@!```)PXM$)$"!PJ'K
MV6X!T#'=BU0D-#'OB?D!P8M$)##!X`6)QXM$)#`/K-`;BU0D),=$)"0`````
MB40D*`M\)"B+1"0@`?F)3"0HB4PD8(G!P>$>BWPD*`^LT`*)S8N4)(`!```)
MQ8M$)$B)7"1(B6PD0('"H>O9;@'0,>N+;"10,=V)Z8ML)"P!P8GXP>`%B40D
M((GX#ZSH&XML)"`)Q0'IB4PD4(E,)""+?"0PBVPD-(M$)$B)^HG^BWPD8,'B
M'@^L[@*)U8N4)(@!```)]8EL)$B!PJ'KV6X!T#-L)$"+5"0D,>^)^0'!BT0D
M((G&#ZS0&\'F!8M4)"R)1"0PBVPD,(M$)"@)]0'I,?^+;"1(B<Z)3"1@B<'!
MX1X/K-`"BY0DD`$``(G+BXPDE`$```G#BT0D0(E<)#"!PJ'KV6Z#T0")RXG1
M,=(!R!':,VPD,(E$)"B)5"0LBU0D4(GPQT0D+``````QZHG1`TPD*,'@!8E$
M)"B)\(ML)"@/K/@;B40D0`ML)$`!Z8E,)%")3"0HBT0D((M4)"2+7"0PQT0D
M)`````#'1"0T`````(G!P>$>#ZS0`HG-BY0DF`$```G%BT0D2(EL)$"!PJ'K
MV6X!T#'KBVPD8(M4)"PQW8GI`<&+1"0HP>`%B40D((M$)"B+;"0@#ZS0&XGR
MB40D2`ML)$B+1"0P`>G!XAZ)U8N4)*`!``")3"0@#ZS^`HM\)%")3"1@"?6!
MPJ'KV6X!T(EL)$@S;"1`BU0D)#'OB?D!P8M$)"")RXG&#ZS0&XM4)"S!Y@6)
M1"0PBT0D*(ML)#")P0GU`>O!X1X/K-`"B5PD4(E<)#")RXN4)*@!```)PXM$
M)$"+;"1(BWPD8,=$)"P`````B5PD8('"H>O9;@'0,=V+5"0T,>^)^0'!BT0D
M,,'@!8G'BT0D,`^LT!N+5"0DQT0D)`````")1"0H"WPD*(M$)"`!^8M\)%")
M3"1`B4PD*(G!P>$>#ZS0`HG-BY0DL`$``(G9"<6+1"1(B>Z!PJ'KV6Z)\XET
M)&@!T#'IBVPD+#'/BU0D-(GYBWPD*`'!B?C!X`6)1"0@B?@/K.@;BVPD((E$
M)$@+;"1(BT0D,`'IB<>)3"1(B4PD((G!#ZS7`L'A'HM$)$")\HG-"?TQ_PGK
M(>J);"1`(=B)P0G1B<Z+C"2X`0``BYPDO`$``(M$)&"!P=R\&X^#TP`QT@'(
MB?$1VHG[`<&+1"0@BWPD+!'3BU0D)(E,)#")7"0TQT0D-`````")QL=$)"P`
M````#ZS0&\'F!8G!"?&+="0HB<B+3"0P`<&+1"1(B4PD4(E,)#")\<'A'@^L
M_@*)SPGWBW0D0(G[B?J)?"1(BWPD)`GS(?(AV(G!BT0D:`G1BY0DP`$``(G.
MB?.!PMR\&X\!T(M4)#0!PXM$)#")Q@^LT!O!Y@6)1"0HBVPD*(M$)%`)]8MT
M)"`!ZXE<)"B)7"1@B?'!X1X/K/X"BWPD2(G+"?.)VHG[B?F)5"10"=,AT2'8
MB<6+1"1`"<V+C"3(`0``@<'<O!N/`<B)Z0'!BT0D*(M4)"R+?"0TQT0D)```
M``#'1"0T`````(G&#ZS0&\'F!8M4)%`)QHM$)&`!\8MT)#")3"1HB4PD((G3
MB?'!X1X/K/X"B<V+?"0LQT0D+``````)]0GK(>J);"1`(=B)P8M$)$@)T8N4
M)-`!``")SHGS@<+<O!N/`="+5"0D`<.+1"0@B<8/K-`;P>8%B40D,(ML)#"+
M1"1H"?6+="0H`>N)7"0PB5PD8(GQBUPD0`^L_@+!X1Z)SXN,)-@!```)]XGZ
MB7PD2`G:(=")^HG%BT0D4"':"=6!P=R\&X^+5"0T`<B)Z0'!BT0D,(G&#ZS0
M&\'F!8E$)"B+;"0H"?4!Z8E,)&B)3"0HBW0D((M\)"2+1"1@QT0D)`````")
M\<'A'@^L_@*+?"1(B<N+C"3@`0``"?.)VHG[B50D4`G3(=B)^XM\)#2)Q8M$
M)$`ATPG=@<'<O!N/BU0D+(GK`<@!PXM$)"B)Q@^LT!O!Y@6+5"10"<:+1"1H
M`?.+="0PB5PD8(E<)""+G"3L`0``B?'!X1X/K/X"B<V)T3'_"?4)Z2'JB6PD
M0"'(B<&+1"1("=&)SHN,).@!``"!P=R\&X^#TP`QT@'(B?$1VHG[`<&+1"0@
MBWPD+!'3BU0D)(E,)#")7"0TBUPD0(G&QT0D-``````/K-`;P>8%B<$)\8MT
M)"B)R(M,)#`!P8M$)&")3"1HB4PD,(GQP>$>#ZS^`HG/"?>)^HE\)$C'1"0L
M``````G:(=")^HM\)"0AVHG!BT0D4`G1BY0D\`$``,=$)"0`````B<Z)\X'"
MW+P;CP'0BU0D-`'#BT0D,(G&#ZS0&\'F!8E$)"B+;"0HBT0D:`GUBW0D(`'K
MB5PD8(E<)"B)\<'A'@^L_@*+?"1(B<L)\XG:B?N)^8E4)%`)TR'1BU0D+"'8
MBWPD-(G%BT0D0`G-BXPD^`$``('!W+P;CP'(B>D!P8M$)"B)Q@^LT!O!Y@6+
M5"10"<:+1"1@`?&+="0PB4PD((E,)&B)TXGQP>$>#ZS^`HG-"?4)ZR'JB6PD
M0"'8B<&+1"1("=&+E"0``@``B<Z)\X'"W+P;CP'0BU0D)`'#BT0D((G&#ZS0
M&\'F!8E$)#"+;"0P"?4!ZXE<)&"+="0HBWPD+(E<)#"+7"1`BT0D:(GQQT0D
M-`````#'1"0L``````^L_@+!X1Z)SXN,)`@"```)]XGZB7PD2`G:(=")^HM\
M)"2)Q8M$)%`AV@G5@<'<O!N/BU0D-,=$)"0``````<B)Z0'!BT0D,(G&#ZS0
M&\'F!8E$)"B+;"0HBT0D8`GUBW0D(`'IB4PD:(E,)"B)\<'A'@^L_@*+?"1(
MB<N+C"00`@``"?.)VHG[B50D4`G3(=B)^XM\)#2)Q8M$)$`ATPG=@<'<O!N/
MBU0D+`'(B>D!P8M$)"B)RXG&#ZS0&\'F!8M4)%`)QHM$)&@!\XMT)#")7"1@
MB5PD((GQP>$>#ZS^`HG-B=$Q_PGU">DAZHEL)$`AR(N<)!P"``")P8M$)$@)
MT8G.BXPD&`(``('!W+P;CX/3`#'2`<B)\1':B?L!P8M$)""+?"0L$=.+5"0D
MB4PD,(E<)#2+7"1`B<;'1"0T`````,=$)"P`````#ZS0&\'F!8G!"?&+="0H
MB<B+3"0P`<&+1"1@B4PD:(E,)#")\<'A'@^L_@*)SPGWB?J)?"1("=HAT(GZ
MBWPD)"':B<&+1"10"=&+E"0@`@``B<Z)\X'"W+P;CP'0BU0D-`'#BT0D,(G&
M#ZS0&\'F!8E$)"B+;"0HBT0D:`GUBW0D(`'KB5PD8(E<)"B)\<'A'@^L_@*+
M?"1(B<L)\XG:B?N)^8E4)%`)TR'1(=B)Q8M$)$`)S8N,)"@"``"!P=R\&X\!
MR(GI`<&+1"0HBU0D+(M\)#3'1"0D`````,=$)#0`````B<8/K-`;P>8%BU0D
M4`G&BT0D8`'QBW0D,(E,)&B)3"0@B=.)\<'A'@^L_@*)S8M\)"P)]0GK(>J)
M;"1`(=B)P8M$)$@)T8N4)#`"``")SHGS@<+<O!N/`="+5"0D`<.+1"0@B<8/
MK-`;P>8%B40D,(ML)#"+1"1H"?6+="0H`>N)7"0PB5PD8(GQBUPD0`^L_@+!
MX1Z)SXN,)#@"```)]XGZB7PD2`G:(=")^HG%BT0D4"':"=6!P=R\&X^+5"0T
M`<B)Z0'!BT0D,(G&#ZS0&\'F!8E$)"B+;"0H"?4!Z8E,)&B)3"0HQT0D+```
M``"+="0@BWPD)(M$)&#'1"0D`````(GQP>$>#ZS^`HM\)$B)RXN,)$`"```)
M\XG:B?N)5"10"=,AV(G[BWPD-(G%BT0D0"'3"=V!P=R\&X^+5"0L`<B)Z0'!
MBT0D*(G+B<8/K-`;P>8%BU0D4`G&BT0D:`'SBW0D,(E<)&")7"0@BYPD3`(`
M`(GQP>$>#ZS^`HG-B=$Q_PGU">DAZHEL)$`AR(G!BT0D2`G1B<Z+C"1(`@``
M@<'<O!N/@],`,=(!R(GQ$=J)^P'!BT0D((M\)"P1TXM4)"2)3"0PB5PD-,=$
M)#0`````B<8/K-`;P>8%B<$)\8MT)"B)R(M,)#`!P8M$)&")3"1HB4PD,(GQ
MP>$>#ZS^`HG+"?.+="1`B=^)VHE<)$B+7"1(QT0D+``````)]R'R(?B+?"0D
MB<&+1"10"=&+E"10`@``B<Z)\8'"W+P;CP'0BU0D-`'!BT0D,(G&#ZS0&\'F
M!8N4)%@"``")1"0HBVPD*(M$)$`)]8MT)"`!Z8ML)&B)3"10B4PD*(GQP>$>
M#ZS^`HG/"?>!PM;!8LH!T#'[BU0D+#'=B7PD0(GI`<&+1"0HB<8/K-`;P>8%
MBU0D-`G&BT0D,`'Q,?^)SHE,)&")P<'A'@^LT`*)S8N4)&`"```)Q8M$)$B)
M;"0PBVPD0('"UL%BR@'0,VPD,#-L)%")Z0'!B?#!X`6)1"0@B?"+;"0@#ZSX
M&XE$)$@+;"1(`>F)3"10B4PD((M$)"B+5"0LQT0D)`````#'1"0L`````(G!
MP>$>#ZS0`HG+BY0D:`(```G#BT0D0(G=B5PD0(M<)#"!PM;!8LH!T(M4)"0Q
MZXML)&`QW8N<)'`"``")Z0'!BT0D(,'@!8E$)"B+1"0@BVPD*`^LT!N)\HE$
M)$@+;"1(BT0D,`'IP>(>#ZS^`HG5B4PD*(E,)&`)]8'#UL%BRHM4)"R)[XML
M)$`!V(E\)$@Q_8GNBVPD4#'UB>D!P8M$)"B)RXG&#ZS0&\'F!8M4)"0)QHM$
M)"`!\S'_B5PD4(G>B<'!X1X/K-`"B<V+E"1X`@``"<6+1"1`B6PD,(ML)$B!
MPM;!8LH!T#-L)#"+5"0L,VPD8,=$)"0`````QT0D+`````")Z0'!B=C!X`6)
M1"0@B=B+;"0@#ZSX&XE$)$`+;"1`BT0D*`'IB4PD((E,)&")P<'A'@^LT`*)
MRXN4)(`"```)PXM$)$B)W8E<)$"+7"0P@<+6P6+*`="+5"0D,>N+;"10,=V+
MG"2(`@``B>D!P8M$)"#!X`6)1"0HBT0D((ML)"@/K-`;B?*)1"1("VPD2(M$
M)#`!Z<'B'@^L_@*)U8E,)"B)3"1("?6!P];!8LJ)[XML)$`!V(E\)#`Q_8GN
MBVPD8#'UB>D!P8M$)"B+5"0LBUPD,(G&#ZS0&\'F!8M4)"3'1"0D``````G&
MBT0D(`'Q,?^)SHE,)%")P<'A'@^LT`*)S8N4))`"```)Q8M$)$");"1`@<+6
MP6+*`=`QZXML)$B+5"0L,=V)Z0'!B?#!X`6)1"0@B?"+;"0@#ZSX&XE$)$@+
M;"1(BT0D*`'IB4PD((E,)&")P<'A'@^LT`*)S8N4))@"```)Q8M$)#");"1(
M@<+6P6+*`=`S;"1`BU0D)#-L)%")Z0'!BT0D(,'@!8E$)"B+1"0@BVPD*`^L
MT!N)\HE$)#`+;"0P`>F)_8GW#ZSO`L'B'HE,)%")3"0HB?C'1"0L`````(G7
MBYPDH`(```G'BVPD2(M$)$"+5"0LB7PD0('#UL%BR@'8,?V)[HML)&`Q]8GI
M`<&+1"0HB<N)Q@^LT!O!Y@6+5"0DQT0D)``````)QHM$)"`!\S'_B5PD8(G>
MB<'!X1X/K-`"B<V+E"2H`@``"<6+1"1(B6PD,(ML)$"!PM;!8LH!T#-L)#"+
M5"0L,VPD4(GI`<&)V,'@!8E$)"")V(ML)"`/K/@;B40D2`ML)$B+1"0H`>F)
M3"0@B4PD4(G!P>$>#ZS0`HG+BY0DL`(```G#BT0D0(G=B5PD0(M<)#"!PM;!
M8LH!T#'KBVPD8#'=B>D!P8M$)"#!X`6)1"0HBT0D((M4)"2+;"0HBYPDN`(`
M`,=$)"P`````#ZS0&XGRB40D2`ML)$B+1"0P`>G!XAX/K/X"B=6)3"1@B4PD
M*`GU@</6P6+*BU0D+(GOBVPD0`'8B7PD2#']B>Z+;"10,?6)Z0'!BT0D*(G&
M#ZS0&\'F!8M4)"0)QHM$)"`!\3'_B<Z)3"10B<'!X1X/K-`"BY0DP`(``(G-
MBXPDQ`(```G%BT0D0(EL)#"+;"1(@<+6P6+*@]$`B<N)T3'2`<@1VC-L)#`Q
MVS-L)&")Z0'!B?`1T\'@!3'2B40D((GPBVPD(`^L^!N)1"1`"VPD0`'I$=.)
MRHE4)$")7"1$B50D(,=$)"0`````BT0D*(M4)"S'1"0L`````(G!P>$>#ZS0
M`HN4),@"``")RXN,),P"```)PXM$)$B)W8'"UL%BRHEL)$B#T0")RXG1,=(!
MR!':BUPD,#'KBVPD4#'=,=N)Z0'!BT0D(!'3BU0D),'@!8E$)"B+1"0@BVPD
M*`^LT!LQTHE$)%`+;"10BT0D,`'I$=.)\HE,)"@/K/X"P>(>B5PD9(N<)-`"
M``")U8E,)&`)]8NT)-0"``"!P];!8LJ)[XML)$B)V8E\)%"#U@`QT@'($?(Q
M_3';B>Z+;"1`,?6)Z0'!BT0D*!'3BU0D+(G&#ZS0&\'F!3'2"<:)\(G>B<L!
MPXM$)"`1UHM4)"2)7"1HB70D;#'_B=Z)P<'A'@^LT`*)S0G%B6PD0(N4)-@"
M``"+1"1(BVPD4,=$)#0`````QT0D)`````"!PM;!8LH!T#-L)$"+5"0L,VPD
M8(GI`<&)V,'@!8E$)"")V(ML)"`/K/@;B40D,`ML)#"+1"0H`>F)3"0PB4PD
M2(G!P>$>#ZS0`HN4).`"``")RXN,).0"```)PXM$)%")W8'"UL%BRHEL)"B#
MT0")RXG1,=(!R!':BUPD0#'KBVPD:#'=,=N)Z0'!BT0D,!'3BU0D-,'@!8E$
M)""+1"0PBVPD(`^LT!LQTHE$)%`+;"10`>D1TXG*B50D4(E<)%2)5"0@BYPD
MZ`(``(GRBT0D0,'B'HML)"@/K/X"B=>+5"0D"?>!P];!8LH!V#']B7PD0(GN
MBVPD2#'UB>D!P8M$)"")Q@^LT!O!Y@6+5"0T"<:)\`'(,?^)QHM$)#")P<'A
M'@^LT`*)S8M4)""+3"0D"<6+1"0HB6PD8`^DT1[!XAZ)5"0PB4PD-(M4)""+
M3"0D#ZS*`L'I`HE,)"2+C"3P`@``B50D((GZ@<'6P6+*`<B+3"1`,>F+;"10
M,<V)Z0'!B?#!X`6)1"0HB?"+;"0H#ZSX&P^D\@6)1"1("VPD2(E4)"R)^L'J
M&XE4)$R)Z`'(B<$#3"00BT0D/(G#QT`$`````(D(BT0D&(ML)##'0PP`````
MQT,4`````,=#'``````!\`ML)"#'0R0`````B4,(B>@#!"2)0Q"+1"1@`T0D
M"(E#&(M$)$`#1"18B4,@BX0D_`(``&4S!10```!U"X'$#`,``%M>7UW#Z)W4
M__^-M@````"-O"<`````A<`/A)L```!55U93@^P<BPU`404(A<F)3"0(=%4/
MM@B$R71<@/D]=%>)PX/#`0^V"X3)=`6`^3UU\2G#BTPD"(LIA>UT+(E4)`R)
MQHG/9I"#[`135E7H%=?__X/$$(7`=0>`?!T`/70?@\<$BR^%[77>@\0<,<!;
M7E]=PXUT)@`QV^NXC70F`(GZ*U0D"(M$)`S!^@*)$(/$'(U$'0%;7E]=PS'`
MPXUV`(V\)P````!3B<.#[!AEH10```")1"0,,<"-5"0(B=CH,____X7`=#J-
MM"8`````BU0D"*%`404(C020BU`$A=*)$'35C78`@\`$BU`$A=*)$'7TC50D
M"(G8Z/G^__^%P'7-BT0D#&4S!10```!U!8/$&%O#Z&[3__^-M"8`````C;PG
M`````%57B<=64XG3@^PX9:$4````B40D*#'`,<"`.CT/E,`!PU/HB=3__X/$
M$(G%B?B-5"08Z)G^__^%P`^$`0$``(/L#(G&4.AFU/__@\00.<4/AM,```"+
M1"08C0R%``````^V!X3`#X2+`0``/#T/A(,!``")^.L.B?:-O"<`````@/H]
M=`J#P`$/MA"$TG7Q*?B-1"@"@^P,BS5`404(4`'.Z*K3__^#Q!"%P(D&#X16
M`0``H4!1!0B+5"08C4\!BQ20#[8'/#V(`G0AA,!U#>L;C;0F`````#P]=!"#
MP0$/MD'_@\(!A,"(`G7LQ@(],<"-M"8`````#[8,`XA,`@&#P`&$R77Q,<"+
M?"0<93,]%`````^%^0```(/$+%M>7UW#C;8`````@\,!#[9#_X/&`83`B$;_
M=>_KS)"-="8`BQ5`404(BS*%]@^$K0```#'`ZP:-="8`B?"-<`&+#+*%R77T
MC02%#````(L-@&$%"(7)=#.#[`A04NC!TO__@\00A<"C0%$%"'1^C0RU````
M`,=$L`0`````B70D&.F]_O__D(UT)@")5"0(@^P,QP6`804(`0```%#HD=+_
M_X/$$(7`=$.-#+4`````@^P$48M4)!")3"044HE$)!10Z/S0__^+1"08@\00
MBTPD#*-`404(ZYPQP.F4_O__N`@````Q]NEB____N/_____I]O[__^A(T?__
MD(VT)@````!55U93B<:![(P```!EH10```")1"1\,<"%]G0%@#X`=1^+1"1\
M93,%%`````^%'P$``('$C````%M>7UW#C78`@^P,5N@WU/__@\00A<")QW3/
MC;8`````@^P,5^B/T___@\00A<")PP^$N@```(![$RX/A(@```"#[`R-:Q-6
MZ`S2__^)+"2)1"0<Z`#2__^+3"0<C40!`HD$).B0T?__B<-86E56:(#?!`AJ
M_VH!4^C;T___@\0<C40D(%!3:@/H:]/__X/$$(/X_W00BT0D+"4`\```/0!`
M``!T:X/L#%/H>M#__X/$$(/L#%/HWL___X/$$.E>____C;8`````#[9#%(3`
M#X1,____/"X/A63___^`>Q4`#X0Z____Z57___^0C70F`(/L#%?H/]/__XDT
M).C7S___@\00Z>#^__^-M"8`````B=CHL?[__^N8Z.K/__^-=@"-O"<`````
M5E.#[!#_-5!1!0CHT-+__XN`A````%N+<`3_-5!1!0CHN]+__P^V6&E8_S50
M404(@^-_Z*C2__^+0`0/MT`0P>`'"<-FB5X"6/\U4%$%".B,TO__BX"$````
MBU@$6/\U4%$%".AWTO__@\0,:@!H5>$$"%#HY]#__XE#'%C_-5!1!0CH6-+_
M_XN`A````(M8!%C_-5!1!0CH0]+__XN`*`0``(E#(%C_-5!1!0CH+M+__XN`
MA````%J+6`3_-5!1!0CH&=+__XN(+`$``(/$$#'2A<ET&H/L#/\U4%$%".C\
MT?__BX`L`0``@\00BU!P@^P,B5,D_S50404(Z-_1__^+@(0```"+0`3'0"@`
M````6/\U4%$%".C#T?__BX"$````BT`$QT`8`````%K_-5!1!0CHI]'__XN`
MA````%F+6`3_-5!1!0CHDM'__XN`.`(``(E#+(/$%%M>PXUV`%.)PX/L%/\U
M4%$%".AOT?__@\0,!3@!``!04VH#Z&[1__^#Q!"%P'0'@\0(,<!;PX/L#/\U
M4%$%".A"T?__BX!(`0``@\00)0#P```]`$```'0C@^P,_S50404(Z!_1__^+
M@$@!``"#Q!`E`/```#T`H```=;.#[`AJ`E/H3]#__X/$$(7`#Y3`@\0(#[;`
M6\/K#9"0D)"0D)"0D)"0D)!55XG'5E.)U8'L(!```&6A%````(F$)!`0```Q
MP&C_#P``C70D%%9HAM\$".C_S?__@\00A<!^8(U8_X!\'`P`=$Z)PX/L!%-J
M+U;H@,___X/$$(7`=$&#[`S_-5!1!0CH>]#__U-65U#H`M#__X/$((N$)`P0
M``!E,P44````=36!Q!P0``!;7E]=PXUT)@"%VW6PC70F`(/L#/\U4%$%".@Z
MT/__@\0,55=0Z(_-__^#Q!#KN^@ES?__D(UT)@"#[!C_-5!1!0CH$M#__VB(
MX00(:""3!`AHE=\$"%#HG<[__X/$+,.)]HV\)P````"#[!C_-5!1!0CHXL__
M_XD$).BZ____6/\U4%$%".C.S___6EEJ`&A5X00(:%7A!`AH4-H$"&BQWP0(
M4.CPSO__@\0LPXVV`````(V_`````%=64X'L$"```&6A%````(F$)`P@```Q
MP.A#S?__@^P(:)'?!`A0:,;?!`AH`1```&H!C5PD)E/HM,___X/$((7`>&6#
M[`1H`!```(V\)!,0``!74^B7S/__@\00A<")QGA&C4`!@^P,4.@BS?__@\00
MA<")PW0Q@^P$5E=0Z+[+___&!#,`@\00B=B+E"0,(```93,5%````'41@<00
M(```6UY?PXUV`#'`Z]_H[\O__^L-D)"0D)"0D)"0D)"0D.D[____C70F`(V\
M)P````!55U93@>PL$```BYPD0!```(U4)!B+O"1$$```9:$4````B80D'!``
M`#'`N-3?!`CH"_?__X/L"(G&:B]3Z+[,__^#Q!"%P'0MB=JXW=\$".@;^/__
MB=B+E"0<$```93,5%`````^%2`$``('$+!```%M>7UW#@^P,4^BAS/__6EF)
M1"04:.K?!`A7Z*#-__^#Q!")Q8M$)`R-?"0<@\`!B40D#(UT)@"%[72=@'T`
M`+C2WP0(#T3HA?9T%8/L"%56Z%K*__^#Q!"%P`^$F@```(/L#%7H1LS__X/$
M$(!\!?\O=1.-="8`@^@!@'P%_R_&1`4``'3Q`T0D##W_#P``#X]#____@^P$
M4VCLWP0(56@0X00(:``0``!J`5?H_LW__X/$%/\U4%$%".B@S?__@\0,!3@!
M``!05VH#Z'_-__^#Q!"%P'4C@^P,_S50404(Z'K-__^+@$@!``"#Q!`E`/``
M`#T`@```=!F#[`AHZM\$"&H`Z+;,__^#Q!")Q>DD____@^P(:@%7Z)',__^#
MQ!"%P'75B?JXW=\$".C.]O__@^P,5^CER___@\00Z:3^___H&,K__Y"-M"8`
M````BT0D!`^V"(3)=!6-4`%FD(#Y+P^V"@]$PH/"`83)=?#SPXVT)@````"-
MO"<`````4X/L&(M<)""%VW1$#[83A-)T/8A4)`^#[`Q3Z!#+__^-1`/_@\00
M#[94)`\YPW(/ZTJ-M@````"#Z`$YPW1!@#@O=/3K+XUV`(V\)P````"#[`QJ
M`NAVRO__@\00A<!T?[HN````9HD0@\086\-FD(`X+W0P@^@!.<-R]#G#=26`
M^B]TR\=$)"#LWP0(@\086^D*R___C78`C;PG`````(`X+W4'@^@!.<-R]"G8
MC5`"@?H`$```=R>#P`%H`!```%!3:(!1!0CH,\O__X/$$+B`404(@\086\.-
MM@````"#Q!@QP%O#B?:-O"<`````5U:#[#1EH10```")1"0L,<"A9.$$"(E$
M)`JA:.$$"(E$)`ZA;.$$"(E$)!*A<.$$"(E$)!:A=.$$"(E$)!JA>.$$"(E$
M)!ZA?.$$"(E$)"*A@.$$"(E$)"8/MP6$X00(9HE$)"JX[M\$".BA]/__N/??
M!`CHE_3__[C_WP0(Z(WT__^X".`$".B#]/__N`_@!`CH>?3__[@?X`0(Z&_T
M__^XU-\$".AE]/__N"O@!`CH6_3__[@UX`0(Z%'T__^X/^`$".A']/__N-W?
M!`CH/?3__[A)X`0(Z#/T__^X4N`$".@I]/__C50D!+A=X`0(Z&OS__^%P'0,
MB<*X->`$".B+]/__C50D!+ANX`0(Z$WS__^%P'0,B<*X@.`$".AM]/__C50D
M!+B+X`0(Z"_S__^%P'0SB<*XU-\$".A/]/__NK?@!`BX#^`$".A`]/__BT0D
M+&4S!10```!U58/$-%Y?PY"-="8`C50D!+B;X`0(Z.KR__^%P'06B<*X*^`$
M".@*]/__Z[F0C;0F`````(UT)!N_K.`$"+D*````\Z9UGXU4)"6X*^`$".C@
M\___ZX_H.<?__XGVC;PG`````(/L'&6A%````(E$)`PQP*$<404(@_C_=!>+
M3"0,93,-%````'4^@\0<PXVV`````(U4)`BX*^`$".AB\O__A<!T'@^V$(#Z
M,`^5P(32#Y7"#[;2(="C'%$%".N]C70F`#'`Z_'HQ\;__XVT)@````"#[`SH
MR,;__X/L#%#H'\;__X/$$(7`=`B+`(/$#,-FD#'`Z_:-M@````"-OP````!5
M5[_#X`0(5E.[N>`$"(/L3(ML)&#'1"0@P^`$"(UT)"AEH10```")1"0\,<#'
M1"0DN>`$",=$)"C&X`0(QT0D++S@!`C'1"0PP>`$",=$)#33X`0(QT0D.```
M``#K(Y"#[`A54(E$)!CH8L7__X/$$(7`=$N%VW0JBP:)WX/&!(G#C50D'(GX
MZ'/Q__^%P'0%@#@`=<J)ZHGXZ)'R__^%VW76BT0D/&4S!10```!U<8/$3%M>
M7UW#D(VT)@````"#[`Q5Z!?'__^+3"08B40D'(D,)(E,)!CH`\?__XM4)!R-
M1`("B00DZ)/&__^#Q`R+3"0,46CJWP0(56@0X00(:O]J`5")1"0HZ-+(__^#
MQ""+5"0(B?CH%/+__^E4____Z&K%__^-=@"-O"<`````55=64X'L+($``(N$
M)$"!``"-5"0LQT0D,.K@!`C'1"0TTM\$",=$)#@`````QT0D2(#@!`C'1"1,
M>>`$"(E$)!#'1"10[^`$"&6A%````(F$)!R!```QP+C4WP0(QT0D5);@!`C'
M1"18]^`$",=$)%P`````QT0D/-[@!`C'1"1`^^`$",=$)$0`````Z#[P__^%
MP'0)@#@`#X7Y`P``Z/S]__^%P(G##X0+!```@^P,4^CYQ?__C40``8/$$(/L
M#%#HB<7__X/$$(`[`(G&B<=T*9"-="8`#[8#@^P,@\,!4&@$X00(:O]J`5>#
MQP+HO,?__X/$((`[`'7<C7PD3+B`X`0(ZQ.)]HV\)P````"#QP2+1_R%P'0V
MC50D+.BM[___A<")PW3G@#@`=.+HK?7__X7`=-F#[`Q3Z.#%__^#Q!"%P(G%
M=5F-M"8`````BUPD,(7;=$B`.P"_`0```'46ZSR-="8`BUR\,(7;=#"#QP&`
M.P!T*(G8Z&'U__^%P'3E@^P,4^B4Q?__@\00A<!TU8G%ZPN)]HV\)P`````Q
M[8/L#(GS5>@#Q?__@\00BPN#PP2-D?_^_O[WT2'*@>*`@("`=.F)U\'O$/?"
M@(````]$UXU[`HG1#T3?`-&#VP.#[`PI\XV<`P0$``!3Z%S$__^)1"0<5HG&
M:`GA!`AH[-\$"%5H#N$$"&K_:@%0Z)O&__^#Q"AHP`$``%;H[<3__X/$$(/X
M_W1U@^P,_S50404(Z"?&__^#Q`P%.`$``%#_="04:@/H(\;__X/$$(7`='2#
M[`S_="08BT0D(/\P:-#A!`AJ`?\U2%$%".BMQ?__@\0@,<"+C"0<@0``93,-
M%`````^%L`D``('$+($``%M>7UW#B?:-O"<`````Z)O$__^+`(/X$0^$>___
M_X/L"%#_="08BT0D(/\P:)3A!`CKH8UV`(/L#/\U4%$%".B*Q?__BX!(`0``
M@\00)0#P```]`$````^%9?___X/L#/\U4%$%".ACQ?__B[!0`0``Z&C"__^#
MQ!`YQ@^%0?___X/L#/\U4%$%".@_Q?__BX!(`0``@\00)?\!```]P`$```^%
M&O___X/L#%/H#</__XU4)#R)Q;B\X`0(Z'WM__^#Q!"%P`^$L@$``(/L#%#H
MN</__UM>4(M$)!S_,.@;]O__@\00A<")PP^$C@$``(/L#%/H)</__X/$$(/X
M`WXMC70#_+\7X00(N04```#SIG4;@_@$#X0M!P``@'P#^R\/A"('``"-M"8`
M````Z&OZ__^%P'4:@^P(:@!3Z/S"__^)1"0H@\00A<`/A3@!``"ZM^`$"+@K
MX`0(,=OH#.[__^@GPO__:%7A!`A0:.S?!`B+="085F@PX00(:O]J`57HF,3_
M_X/$(.LWC78`Z!O#__^#.!%U0.CQP?__@\,!@^P,:%7A!`A34&CLWP0(5F@^
MX00(:O]J`57H7\3__X/$,(/L"&C``0``5>BNPO__@\00@_C_=+:#[`S_="08
MZ'K`__^)ZKC4WP0(Z'[M__^)+"3H1OK__X/$$(GHZ>3]__^-="8`@^P,4(E$
M)!SH*_K__XM$)!R)!"3H;\+__X/$$.F__?__O@$```"XWN`$".L.C78`BT2T
M/(/&`87`="F-5"0LZ/3K__^%P'3H@#@`=..#[`Q0Z#+"__^#Q!"%P'33B</I
MLOO__[@-````N^/@!`CIL_O__Y"-="8`BT0D$(L8Z6?^__]J`FK_:NZ+="0D
M5NCEP/__@\0,:@:-A"0D`0``4%;H@K___X/$$("\)!P!````=0Z`O"0=`0``
M0P^$2`8``&H`:@!J`/]T)"3HJ,#__\=$)'`!(T5GQT0D=`````#'1"1XB:O-
M[\=$)'P`````QX0D@````/[<NIC'A"2$`````````,>$)(@```!V5#(0QX0D
MC`````````#'A"20````\.'2P\>$))0`````````QX0DF`````````#'A"2<
M`````````,>$)*``````````QX0DI`````````#'A"3H`````````(/$$(EL
M)!R0C;0F`````(/L!&@`@```C80D)`$``%#_="0DZ)>^__^#Q!"%P(G##XX#
M`@``B[0DB````(N\)(P```")V)G!X`.)7"00B50D%`'P@_\`#X?#`0``.<8/
MA[L!``"+M"20````B[PDE````(M4)!2)A"2(````BT0D$,>$)(P`````````
M#ZS0'<'J'0'&BX0DV````!'7B;0DD````(F\))0```"%P`^$6P$``+I`````
MC8PDF````"G".=.)U@].\X/L!`'(5HV,)"0!``!14.@BOO__BX0DZ`````'P
MB80DZ````(/$$(/X0`^%%O___XV$)!P!```I\XTL,(U$)&#HP<3__Y"#^S\/
MC@8$``"#ZT")W\'O!HUW`<'F!@'NC;0F`````(M%`(/%0(F$))@```"+1<2)
MA"2<````BT7(B80DH````(M%S(F$)*0```"+1=")A"2H````BT74B80DK```
M`(M%V(F$)+````"+1=R)A"2T````BT7@B80DN````(M%Y(F$)+P```"+1>B)
MA"3`````BT7LB80DQ````(M%\(F$),@```"+1?2)A"3,````BT7XB80DT```
M`(M%_(F$)-0```"-1"1@Z/3#__\Y[@^%3/___\'G!BG[:D135HV$)*0```!0
MZ':^__^)G"3H````@\00Z0?^__^-M"8`````C:PD'`$``.GT_O__C70F`(NT
M))````"+O"24````@\8!@]<`Z3K^__^+;"0<@^P,_W0D).@WP/__BX0DH```
M`(N<))@```"+M"2<````BY0DI````(E$)"")V`^L\`.)5"0D@^`_C5`!QH0$
MJ````("#Q!"#^C@/CYD"``"X.````(V,))@````IT`'*@_@$#X._`@``A<!T
M"Z@"Q@(`#X5[`P``BU0D%(M$)!"-O"3S````B)PDUP````^LT!B+5"04B(0D
MT````(M$)!`/K-`0BU0D%(B$)-$```"+1"00#ZS0"(B$)-(````/MD0D$(B$
M)-,```")V`^L\!B(A"34````B=@/K/`0B(0DU0```(G8#ZSP"(B$)-8```"-
M1"1@Z)C"__^+3"1@BUPD9(G.B(PDX@````^LWAB)\(G.#ZS>$(B$)-\```")
M\HG.BTPD:`^LW@B(E"3@````B?.)SHB,).8```"(G"3A````BUPD;`^LWAB)
M\HG.#ZS>$(B4).,```")\HG.BTPD<`^LW@B(E"3D````B?.)SHB,).H```"(
MG"3E````BUPD=`^LWAB)\HG.#ZS>$(B4).<```")\HG.BTPD>`^LW@B(E"3H
M````B?.)SHB,).X```"(G"3I````BUPD?`^LWAB)\HG.#ZS>$(B4).L```")
M\HG.BXPD@`````^LW@B(E"3L````B?.)SHB,)/(```"(G"3M````BYPDA```
M``^LWAB)\HG.#ZS>$(B4).\```")\HG.#ZS>"(B4)/````")\XVT).````"(
MG"3Q````C9PD&P$``.D)````C78`#[8&@\8!@^P,#[;`4&@$X00(:O]J`5>#
MQP+H$;[__X/$(#G[==K&A"0;`0```&A5X00(C80D]P```%!H[-\$"/]T)!AH
M(>$$"&K_:@%5Z-V]__^#Q"#IC_G__XM$)!"+4`2%T@^$UOC__X/L#%*)5"0@
MZ+F[__^#Q!"#^`,/AKWX__^+5"00OQSA!`BY!0```(UT`OSSI@]$VNFA^/__
MB>[IP_S__XV,))@```"X0`````'1*=")PG0-,<#&!`$`@\`!.=!R]8U$)&"-
MO"28````Z'G`__^Y#@```#'`\ZOI4/W__XU*!,<"`````,=$`OP`````@^'\
M*<H!PH/B_(/Z!`^"+/W__X/B_#'`QP0!`````(/`!#G0<O+I%/W__X"\)!X!
M``!!#X6J^?__@+PD'P$``$,/A9SY__^`O"0@`0``2`^%COG__X"\)"$!``!%
M#X6`^?__:@)J_VK&BW0D)%;H)[K__X/$#&HIC80D)`$``%!6Z,2X__]H5>$$
M"(V$)#`!``!0:.S?!`C_="0H:"'A!`AJ_VH!5>B/O/__@\0PZ4'X__^-M"8`
M````,?]FB7P"_NEY_/__Z!^Y___K#9"0D)"0D)"0D)"0D)!55U93@^PH9:$4
M````B40D&#'`_S50404(Z/*[__^-5"08QD!E`;@/X`0(Z%#D__^#Q!"%P'0)
M@#@Q#X10`@``Z-OO__^#[`S_-5!1!0CHO;O__VH+:@%H3^$$"%#HKKG__X/$
M((7`#X2S````@SV(804(`8M`#(MX&`^.H````#'VNP$```#K,8VT)@````"+
M10R#[`A0H81A!0C_-)CHO+?__X/$$(7`=66AB&$%"(/#`8/&`3G8?EN#[`S_
M-5!1!0CH2+O__VH`5E=0Z*ZZ__^#Q""%P'0WBRB+10@E``0@`#T`!```=*:#
M[`S_-5!1!0CH&+O__VH":@!54.A]N/__@\0@ZXN0C;0F`````*&(804(C5#_
M.?(/A#`!``"#[`S_-5!1!0CHXKK__VH#:@%H5.$$"%#HT[C__X/$((7`B<-T
M-(M`#(/L#(LP_S50404(Z+>Z__^#Q`QH5N$$"%90Z`BX__^+0PR#Q!"+&/9#
M"D`/A1`"``"#[`S_-5!1!0CHB+K__VH#:@%H6^`$"%#H>;C__X/$((7`B<9T
M.8U4)`BXW=\$".C2XO__A<")PP^$:`$``(M&#(/L#(LX_S50404(Z$6Z__^#
MQ`Q35U#HFK?__X/$$(/L#/\U4%$%".@INO__C50D&,9`90"XU-\$".B'XO__
M@\00A<")PZ.,804(#X25````@^P(:,`!``!0Z*>X__^-4`&#Q!"#^@%V"8/X
M$0^%C@$``(M$)`QE,P44````#X5X`0``@\0<6UY?7<.-=@"-O"<`````@_@!
M#X['_O__NP$```!FD(/L#/\U4%$%"(/#`>B?N?__7EU74.A&MO__@\00.1V(
M804(?]OIEO[__XVV`````(!X`0`/A*O]___IH?W__Y"#[`S_-81A!0CH`O'_
M_X/$$(7`HXQA!0@/A.L```"+1@R+/81A!0B+&(M#""4`!"``/0`$```/A8T`
M``"+0PR#[`A74.AGMO__B<>+1@R#Q!"+&(M#""4`!"``/0`$``!U28M##%=0
MH81A!0C_,&A(X@0(Z(BW__^0C;0F`````*&$804(@^P,BSB+1@R+&/\U4%$%
M".C6N/__B?J)V.CMY___@\00Z8[^__^#[`S_-5!1!0CHM[C__VH":@!34.@<
MMO__@\0@ZYR#[`S_-5!1!0CHF;C__VH":@!34.C^M?__@\0@Z57___^#[`S_
M-5!1!0CH>+C__UI94U#H?[?__X/$$.G1_?__@^P,:"3B!`CHZK;__^A5M?__
M4*&$804(4_\P:'#B!`CHTK;__V:05E.#[!"+="0<5NA1Z___#[80@\00B<.$
MTG05C4`!9I"`^B\/MA`/1-B#P`&$TG7PZ-OM__^%]G0>A<!T&H`^`'05@^P(
M:`GA!`A3Z#"T__^#Q!`YV'0&@\0$6U[#@\0$B?!;7NF7X___C;0F`````(/L
M&/\U4%$%".C"M___6EEJ_U#H2+7__UC_-5!1!0CHK+?__X/$#&H`:(##!`A0
MZ&RW__^#Q!S#9I!FD&:09I!3Z"JZ__^!PRIQ``"#[`C_LQ@!``#_="0<_W0D
M'/]T)!SH"K7__X/$&%O#9I!FD)!55S'_5E/H];G__X'#]7```(/L#(ML)""-
ML_S^___H2;/__XV#^/[__RG&P?X"A?9T(XVV`````(/L!/]T)"S_="0L5?^4
MN_C^__^#QP&#Q!`Y]W7C@\0,6UY?7<.-=@#SPP``4X/L".B3N?__@<.3<```
M@\0(6\,#`````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E
M:2\E<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$52
M3$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!
M4E]!4D=67S``4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!0
M05)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!
M4E]#3$5!3CT`,0!,24)0051(`$193$1?3$E"4D%265]0051(`%-(3$E"7U!!
M5$@`55-%4@!365-414T`+W1M<`!414U01$E2`%1-4`!54T523D%-10`E,#)X
M`'!A<BT`)7,E<R5S)7,`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T
M96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``M90`M+0``
M``!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(`````!P97)L>'-I
M+F,````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R
M(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R
M>0`````E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@````!E=F%L("=E>&5C("]U<W(O8FEN+W!E
M<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L
M("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%
M04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN
M9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P
M=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP
M*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N
M92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U0
M3$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I
M<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P
M+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M
M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P
M87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X
M("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM
M;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N
M86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E
M;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T
M;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]
M"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9)
M;G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*
M:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=6
M7S!]("D@>PI`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N
M+B`D14Y6>U!!4E]!4D=#?2`M(#$I.PHD,"`]("1%3E9[4$%27T%21U9?,'T[
M"GT*96QS92!["F9O<B`H:V5Y<R`E14Y6*2!["F1E;&5T92`D14Y6>R1??2!I
M9B`O7E!!4E]!4D=67R\["GT*?0IM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>
M35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O
M7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM
M("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P*
M*3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A
M<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@
M<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN
M;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G;F%M93L*
M;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H,2D*>PHD
M;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K(%]&2"P@
M+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D<')O9VYA
M;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D;V9F<V5T
M.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A72!U;FQE
M<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U9BP@(EQN
M4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E="`]/2`D
M<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J/2`R.PI]
M"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X("T@-#L*
M<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E
M:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#(["G)E860@
M7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*;7D@
M)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I
M;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^
M('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E
M;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH
M/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@*"1O=70L("1F:6QE;F%M92D@/2!?
M=&5M<&9I;&4H)&5X="P@)&-R8RD["FEF("@D;W5T*2!["F)I;FUO9&4H)&]U
M="D["G!R:6YT("1O=70@)&)U9CL*8VQO<V4@)&]U=#L*8VAM;V0@,#<U-2P@
M)&9I;&5N86UE.PI]"B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE
M?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA
M;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_
M<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I
M;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PIO=71S
M*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*;W!E;B!M>2`D;W5T+"`G/B<L("1F
M:6QE;F%M92!O<B!D:64@)"$["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@
M)&)U9CL*8VQO<V4@)&]U=#L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L
M;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@
M/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA
M;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS
M=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@
M)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R
M97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H
M("AK97ES("5R97%U:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L
M95Q%)"\["B1K97D@/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES
M='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD
M;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%
M3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN
M;6]D92@D9F@I.PIP<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D
M9F@L(#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`H)&]U="P@)&YA
M;64I(#T@7W1E;7!F:6QE*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*:68@
M*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D9FEL96YA;64M
M/GMB=69].PIC;&]S92`D;W5T.PI]"F]P96X@;7D@)&9H+"`G/"<L("1N86UE
M(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB
M.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E
M($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E
M<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O
M<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O
M7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D
M9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN
M<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*
M;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D
M8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%2
M7T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R
M:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'
M?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T
M:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI
M8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@
M("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!
M4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?
M05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P
M87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2![
M"B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA
M<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D
M,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*
M)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD
M;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$[
M"GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@
M;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D
M,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD[
M"FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]('-H
M:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!<F-H
M:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@)&9H
M+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*
M8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@
M07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE
M(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF
M("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM
M;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<
M4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT[
M"FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L
M("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID
M:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B
M4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L
M"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A
M=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`[
M"FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R
M(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM
M>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY
M("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@
M/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N
M9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L
M;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!
M4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI
M=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!S;W)T('L*
M;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0I](&=R97`@>PHA+T)31%!!3B\*
M?2!G<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*+UY?/"@N*RDD
M+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B1F
M:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O
M;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H
M<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C
M:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>
M*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N
M*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL
M87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E
M9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I
M9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\[
M"F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F
M:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0[
M"FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]
M"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O
M<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)
M3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^
M87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L
M("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M
M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!
M<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F
M:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?
M;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@
M?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D52
M4TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S
M:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B
M8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@
M)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H
M)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C
M='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B
M('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@
M(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H
M<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M
M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L
M("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P
M;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL
M96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O
M;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ
M05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L
M("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I
M970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0
M?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A
M8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE
M;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M
M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO
M/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E
M>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I
M;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L
M<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S
M=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H
M<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!
M;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@
M6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP
M87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H
M:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`
M7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A
M=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@
M*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK
M<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W
M:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB
M.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER
M92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q
M=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO
M.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*
M<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I
M;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR
M97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@
M0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E
M(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L
M('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A
M;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R
M8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA
M<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E
M<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"![
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E
M86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A
M=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII
M9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@
M/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I
M('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D
M14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U
M<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N
M9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D
M9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A
M9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@
M/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@
M?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D52
M4TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S
M:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA
M;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E
M;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X
M+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I
M9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[
M4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT
M96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?=&5M<&9I;&4@>PIM>2`H)&5X="P@)&-R8RD@/2!`7SL*;7D@*"1F:"P@
M)&9I;&5N86UE*3L*)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="([
M"FEF("@D14Y6>U!!4E]#3$5!3GTI('L*=6YL:6YK("1F:6QE;F%M92!I9B`M
M92`D9FEL96YA;64["G!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*?0IE;'-E
M('L*<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE
M*3L*?0IO<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM
M;V1E*"1F:"D["G)E='5R;B@D9F@L("1F:6QE;F%M92D["GT*<W5B(%]S971?
M<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD
M("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@
M)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N
M9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P
M<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.
M04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@
M,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R
M;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5]
M(BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*
M9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%
M+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0
M?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O
M;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2([
M"B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E
M=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T
M0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D[
M"B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I
M+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%2
M7TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.
M5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%
M35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I
M('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@
M5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?
M)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@
M("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@
M)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,
M3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL
M(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@
M:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S
M('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G
M9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI
M=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN
M960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P
M<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X
M<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2
M.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H
M0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C
M<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN
M*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X
M:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X
M:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`
M`1L#.^@````<````0'+__P0!``"`=O__\`T``(!Y__\H`0``@)[__VP!```P
MG___T`$``+"?___T`0``T*'__W0"```PH___+`,``)"D__^X`P``,*7__Q0$
M``#PI?__L`0``""F___8!```<*;__Q`%```PI___G`4``$"G__^P!0```*G_
M_ZP&```PJ?__P`8``""J__\@!P``X*O__U`'``!0K/__;`<``("L__^0!P``
ML*W__P`(````NO__W`L``-"]__]L#0``0+[__[@-``"`OO__,`X``+"^__]<
M#@``$+___Z@.```4``````````%Z4@`!?`@!&PP$!(@!```@````'````#1Q
M__\P!`````X(1@X,2@\+=`1X`#\:.RHR)")`````0````%!X___S)````$$.
M"(4"00X,AP-$#A"&!$$.%(,%1@Z@!@/<)`H.%$'##A!!Q@X,0<<."$'%#@1!
M"P```&````"$````#)W__Z8`````20X(A0)!#@R'`T$.$(8$00X4@P5##C`"
M1`XT00XX00X\00Y`2`XP5PH.%$/##A!!Q@X,0<<."$'%#@1%"UH.%$7##A!!
MQ@X,0<<."$'%#@0````@````Z````%B=__]R`````$$."(,"10X@`F4*#@A!
MPPX$00M\````#`$``+2=__\8`@```$$."(4"00X,AP-##A"&!$$.%(,%10Y,
M5PY02`Y`6`Y,0PY02`Y``DL.3$<.4$H.0`)T"@X40<,.$$'&#@Q!QPX(0<4.
M!$<+`E`.2$$.3$$.4$@.0&T.3$L.4$@.0$X.1$$.2$D.3$4.4$P.0````+0`
M``",`0``5)___U8!````00X(A0)!#@R'`T$.$(8$00X4@P5(#J`!;`H.%$'#
M#A!!Q@X,0<<."$'%#@1$"T,.K`%!#K`!2`Z@`4\.K`%!#K`!2`Z@`5<.K`%$
M#K`!9`ZL`4$.J`%!#JP!00ZP`44.M`%"#K@!0@Z\`4$.P`%(#J0!10ZH`4$.
MK`%"#K`!2`Z@`5@.K`%!#K`!2`Z@`4,.K`%!#K`!2`Z@`78.K`%!#K`!4`Z@
M`0"(````1`(``/R?__]=`0```$$."(8"00X,@P-##AQ&#B!,#AQ)#B!*#AQ&
M#B!9#AQ&#B!/#AQ&#B!(#A1"#AA%#AQ!#B!)#AQ&#B!/#AQ&#B!/#AQ&#B!,
M#AQ)#B!.#A!)#AQ&#B!.#A!&#AQ)#B!6#AQ&#B!6#AQ&#B!,#AQ)#B!1#@Q!
MPPX(0<8.!%@```#0`@``T*#__Y$`````00X(@P)%#AQ&#B!(#A1&#AA!#AQ"
M#B!(#A!'"@X(0\,.!$$+0PX<1@X@3@X03PX<1@X@3@X03PX80@X<00X@2`X0
M2`X(1,,.!```F````"P#```4H?__NP````!!#@B%`D$.#(<#0PX0A@1!#A2#
M!4@.M"!4#K@@10Z\($4.P"!(#K`@4PZT($$.N"!"#KP@00[`($@.L"!'#KP@
M1@[`($8.Q"!!#L@@00[,($$.T"!(#K`@5@H.%$'##A!!Q@X,0<<."$'%#@1%
M"TL.O"!&#L`@2`ZT($$.N"!!#KP@00[`($@.L"``)````,@#```XH?__)P``
M``!##AQ&#B!*#B1%#BA%#BQ!#C!(#@0``#0```#P`P``0*'__T0`````0PX<
M1@X@3@X<1@X@1@X<00X80@X<10X@10XD10XH10XL00XP2`X$B````"@$``!8
MH?__L0````!!#@B'`D$.#(8#00X0@P1&#J!`5PZH0$4.K$!!#K!`10ZT0$4.
MN$!"#KQ`10[`0$@.H$!'#J1`10ZH0$@.K$!!#K!`2`Z@0$P.K$!!#K!`2`Z@
M0$D.I$!!#JA`00ZL0$$.L$!,#J!`6`H.$$'##@Q!Q@X(0<<.!$0+```0````
MM`0``(RA__\%`````````/@```#(!```B*'__[@!````00X(A0)!#@R'`T$.
M$(8$00X4@P5&#L`@;@[(($0.S"!!#M`@2`[`(&P*#A1!PPX00<8.#$''#@A!
MQ0X$00M##LP@00[0($8.S"!!#L@@20[,($$.T"!(#L`@;`[(($$.S"!!#M`@
M2`[`($L.S"!!#M`@2`[`(&P.Q"!!#L@@10[,($$.T"!%#M0@10[8($(.W"!!
M#N`@2`[,($8.T"!(#L0@1@[(($$.S"!"#M`@2`[`($<.S"!&#M`@3@[`($\.
MR"!%#LP@0@[0($@.P"!*#L@@0@[,($$.T"!(#L`@4P[,($$.T"!(#L`@`!``
M``#$!0``3*+__R(`````````7````-@%``!HHO__YP````!!#@B#`D,.(%8.
M+$$.,$P.(&P.+$(.,$@.($\*#@A!PPX$0PM@"@X(0<,.!$\+80XD00XH00XL
M10XP2`X@2`H."$'##@1'"T,."$/##@0`+````#@&``#XHO__MP$```!!#@B'
M`D$.#(8#0PY``UL!"@X,0<8."$''#@1&"P``&````&@&``"(I/__:0````!#
M#B!F"@X$1PL``"````"$!@``W*3__R0`````0PX02`X<00X@2`X020H.!$,+
M`&P```"H!@``Z*3__R8!````00X(A0)!#@R'`T8.$(8$00X4@P5(#F`"4@YH
M00YL00YP3`Y@`D(*#A1!PPX00<8.#$''#@A!Q0X$20M##FQ!#G!L#F1%#FA%
M#FQ!#G!%#G1"#GA"#GQ!#H`!3`Y@``#8`P``&`<``*BE__]!#````$$."(4"
M00X,AP-!#A"&!$$.%(,%1@[`@@("IP[,@@)!#M""`DP.P(("0P[,@@)!#M""
M`D@.P(("5`[,@@)$#M""`D4.U(("0@[8@@)"#MR"`D$.X(("2P[`@@("0P[,
M@@)!#M""`D@.P(("`D,.S(("00[0@@)(#L""`E8.S(("0P[0@@)(#L""`G4.
MS(("2@[0@@)*#M2"`D<.V(("10[<@@)!#N""`D4.Y(("0@[H@@)"#NR"`D$.
M\(("2`[(@@)%#LR"`D$.T(("2`[`@@)(#LR"`D8.T(("2`[$@@)&#LB"`D0.
MS(("0@[0@@)(#L""`D<.S(("1`[0@@)&#M2"`D4.V(("0@[<@@)&#N""`D@.
MP(("7`H.%$'##A!!Q@X,0<<."$'%#@1*"U,*#LB"`D$.S(("1`[0@@)&#M2"
M`D4.V(("10M##LR"`D8.T(("3@[`@@)3#LR"`D8.T(("4P[`@@)+#LR"`D8.
MT(("3@[`@@)3#LR"`D$.T(("6`[`@@)+#LR"`D$.T(("1@[,@@)!#LB"`D$.
MS(("1@[0@@)(#L""`DT.S(("00[0@@)(#L""`GX.R(("0@[,@@)!#M""`DP.
MP(("8P[$@@)!#LB"`D4.S(("10[0@@)%#M2"`D(.V(("0@[<@@)!#N""`D@.
MP(("6@[,@@)%#M""`D$.U(("00[8@@)%#MR"`D$.X(("10[D@@)"#NB"`D(.
M[(("00[P@@)(#L""`D,.R(("10[,@@)!#M""`D@.P(("2`[,@@)$#M""`EP.
MP(("3@[,@@)!#M""`E@.P(("=`[,@@)!#M""`D@.P((";`[$@@)"#LB"`D(.
MS(("10[0@@)(#L2"`D(.R(("2`[,@@)!#M""`D@.P(("6@[$@@)"#LB"`D(.
MS(("1`[0@@("H0[`@@)/#L2"`D4.R(("2`[,@@)$#M""`D@.P(("`J$.Q(("
M0P[(@@)(#LR"`D$.T(("6`[`@@("^@[$@@)!#LB"`D$.S(("2`[0@@)/#L""
M`GP.S(("1`[0@@("0`[`@@(#!0(.S(("1`[0@@)%#M2"`D(.V(("0@[<@@)!
M#N""`DL.P(("40[$@@)(#LB"`D4.S(("1`[0@@)%#M2"`D(.V(("0@[<@@)!
M#N""`D@.P(("5P[,@@)!#M""`DP.P(("`N$.Q(("0@[(@@)"#LR"`D4.T(("
M2`[$@@)"#LB"`D@.S(("00[0@@)*#M2"`D@.V(("10[<@@)$#N""`D4.Y(("
M0@[H@@)"#NR"`D$.\(("2`[`@@(`C`$``/0*```<KO__S@,```!!#@B%`D$.
M#(<#00X0A@1!#A2#!4,./%(.0%H.,%4./$8.0$<.1$(.2$4.3$$.4$@.,'$.
M.$$./$@.0$@.,%8./$8.0$<.1$$.2$$.3$$.4$@.,%@./$8.0$<.1$(.2$$.
M3$$.4$@.,%T./$8.0$<.1$(.2$4.3$$.4$@.,$P./$@.0$@.-$4..$$./$$.
M0$L.,$\./$8.0$<.1$(.2$4.3$$.4$@.,&0./$@.0$@.-$$..$$./$$.0$@.
M,$,./$8.0%H.,%(..$4./$$.0$L.,&(*#A1!PPX00<8.#$''#@A!Q0X$2PM3
M#CQ&#D!)#CQ!#CA!#CQ!#D!(#C!F#CQ&#D!(#C!Q#CA!#CQ!#D!-#C!5"@XT
M00XX1PX\10Y`30M(#CQ-#D!1#C!(#CQ&#D!'#D1"#DA!#DQ!#E!(#C!%#CQ&
M#D!'#D1"#DA!#DQ!#E!(#C!(#CQ&#D!&#CQ!#CA!#CQ!#D!(#C!("@X\10Y`
M10M&#C1&#CA"#CQ%#D```$@```"$#```7+#__VD`````00X(A@)!#@R#`T,.
M'$4.($L.$'`.&$4.'$$.($@.$$<*#@Q!PPX(0<8.!$$+0PX,0\,."$'&#@0`
M```T````T`P``("P__\X`````$,.'$8.($8.'$$.&$(.'$$.($8.'$8.($@.
M%$(.&$4.'$$.($@.!#P````(#0``B&C__PH"````1`P!`$<0!0)U`$4/`W5T
M!A`&`G5\$`,"=7@#BP$*P0P!`$'#0<9!Q4,,!`1!"P`H````2`T``$BP__\K
M`````$$."(,"3@X01@X41`X81`X<1`X@2`X(0<,.!$@```!T#0``3+#__UT`
M````00X(A0)!#@R'`T,.$(8$00X4@P5.#B!G#B1$#BA$#BQ!#C!-#B!'#A1!
MPPX00<8.#$''#@A!Q0X$```0````P`T``&"P__\"````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````H)D$"("9!`@``````0````$````!````!0(`
M``$```!4`@``#````&R2!`@-````9-\$"!D```#X3@4(&P````0````:````
M_$X%"!P````$````]?[_;ZR!!`@%````J(D$"`8````(@P0("@```!T%```+
M````$````!4``````````P````!0!0@"````$`(``!0````1````%P```%R0
M!`@1````+)`$"!(````P````$P````@```#^__]OG(\$"/___V\"````\/__
M;\:.!`@`````````````````````````````````````````````````````
M````````````````!$\%"```````````II($"+:2!`C&D@0(UI($".:2!`CV
MD@0(!I,$"!:3!`@FDP0(-I,$"$:3!`A6DP0(9I,$"':3!`B&DP0(EI,$"*:3
M!`BVDP0(QI,$"-:3!`CFDP0(]I,$"`:4!`@6E`0()I0$"#:4!`A&E`0(5I0$
M"&:4!`AVE`0(AI0$"):4!`BFE`0(MI0$",:4!`C6E`0(YI0$"/:4!`@&E00(
M%I4$"":5!`@VE00(1I4$"%:5!`AFE00(=I4$"(:5!`B6E00(II4$"+:5!`C&
ME00(UI4$".:5!`CVE00(!I8$"!:6!`@FE@0(-I8$"$:6!`A6E@0(9I8$"':6
M!`B&E@0(EI8$"*:6!`BVE@0(``````````#_____M.($"$=#0SH@*%5B=6YT
M=2`U+C,N,2TS=6)U;G1U,RD@-2XS+C$@,C`Q-3$R,38`1T-#.B`H56)U;G1U
M(#0N.2XS+3AU8G5N='4R*2`T+CDN,P``+G-H<W1R=&%B`"YI;G1E<G``+FYO
M=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS
M>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD
M>6X`+G)E;"YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I;FD`+G)O9&%T
M80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A
M<G)A>0`N:F-R`"YD>6YA;6EC`"YG;W0N<&QT`"YD871A`"YB<W,`+F-O;6UE
M;G0`````````````````````````````````````````````````````````
M``L````!`````@```%2!!`A4`0``$P```````````````0`````````3````
M!P````(```!H@00(:`$``"````````````````0`````````(0````<````"
M````B($$"(@!```D```````````````$`````````#0```#V__]O`@```*R!
M!`BL`0``7`$```4`````````!`````0````^````"P````(````(@P0("`,`
M`*`&```&`````0````0````0````1@````,````"````J(D$"*@)```=!0``
M```````````!`````````$X```#___]O`@```,:.!`C&#@``U`````4`````
M`````@````(```!;````_O__;P(```"<CP0(G`\``)`````&`````@````0`
M````````:@````D````"````+)`$""P0```P````!0`````````$````"```
M`',````)````0@```%R0!`A<$```$`(```4````8````!`````@```!\````
M`0````8```!LD@0(;!(``",```````````````0`````````=P````$````&
M````D)($")`2```P!``````````````0````!````((````!````!@```,"6
M!`C`%@``"```````````````"`````````"+`````0````8```#0E@0(T!8`
M`))(`````````````!``````````D0````$````&````9-\$"&1?```4````
M```````````$`````````)<````!`````@```'C?!`AX7P``V$``````````
M````!`````````"?`````0````(```!0(`4(4*```.P```````````````0`
M````````K0````$````"````/"$%"#RA``#4#0`````````````$````````
M`+<````.`````P```/A.!0CXO@``!```````````````!`````````##````
M#P````,```#\3@4(_+X```0```````````````0`````````SP````$````#
M`````$\%"`"_```$```````````````$`````````-0````&`````P````1/
M!0@$OP``^`````8`````````!`````@```"&`````0````,```#\3P4(_+\`
M``0```````````````0````$````W0````$````#`````%`%"`#````4`0``
M```````````$````!````.8````!`````P```!11!0@4P0``$```````````
M````!`````````#L````"`````,```!`404(),$``%00`````````````"``
M````````\0````$````P`````````"3!``!/```````````````!`````0``
I``$````#``````````````!SP0``^@```````````````0``````````
